@@ -15,7 +15,7 @@ def generate_codon_to_amino_table(codon_usage_table):
     return codon_to_amino_table
 
 
-RANDOM_CODON_USAGE_TABLE = json.loads(pkgutil.get_data('copter', 'codon_usage_tables/random.json'))
+RANDOM_CODON_USAGE_TABLE = json.loads(pkgutil.get_data('copter', 'codon_usage_tables/random.json').decode('utf-8'))
 BACTERIAL_CODON_TO_AMINO_TABLE = generate_codon_to_amino_table(RANDOM_CODON_USAGE_TABLE)
 
 
@@ -32,6 +32,11 @@ def amino_to_codon(amino, codon_usage_table=RANDOM_CODON_USAGE_TABLE):
             return str(codon)
 
 
+def codon_to_amino(codon,
+                   codon_to_amino_table=BACTERIAL_CODON_TO_AMINO_TABLE):
+    return codon_to_amino_table.get(codon)
+
+
 def codon_to_codon(codon,
                    codon_to_amino_table=BACTERIAL_CODON_TO_AMINO_TABLE,
                    codon_usage_table=RANDOM_CODON_USAGE_TABLE):
